! This file is part of HiggsBounds
!  -KW
!******************************************************************
module S95tables_type1
!******************************************************************      

 implicit none
 
 !table type 1-----------------------------      
 type table1      
  integer :: id,nx,particle_x !see usefulbits.f90 for key to particle codes n.b. they're NOT pdg
  character(LEN=45) :: label
  character(LEN=3) :: expt      
  double precision :: xmax,xmin,sep,deltax
  double precision, allocatable :: dat(:,:) !in dat(a,b), a=row, b=1,2 for obs,pred 
 end type
 !------------------------------------------ 

 integer,parameter :: file_id_1=10 !same as file_id_common in usefulbits.f90

 contains

 !************************************************************ 
 subroutine initializetables_type1_blank(tablet1)
 !***********************************************************  
 ! still leaves dat unallocated
  integer:: i
  type(table1) :: tablet1(:)

  do i=lbound(tablet1,dim=1),ubound(tablet1,dim=1)
   tablet1(i)%id         = -1
   tablet1(i)%nx         = -1
   tablet1(i)%particle_x = -1
   tablet1(i)%label      = ''
   tablet1(i)%expt       = ''
   tablet1(i)%xmax       = -1.0D0
   tablet1(i)%xmin       = -1.0D0
   tablet1(i)%sep        = -1.0D0
   tablet1(i)%deltax     = -1.0D0
  enddo
 
 end subroutine initializetables_type1_blank

 !************************************************************ 
 subroutine copy_type1(tablet1_orig,tablet1_copy)
 !***********************************************************  
 ! note tablet1_1,tablet1_2 are not arrays 
 ! still leaves dat uncopied
  type(table1) :: tablet1_orig
  type(table1) :: tablet1_copy

  tablet1_copy%id         = tablet1_orig%id
  tablet1_copy%nx         = tablet1_orig%nx
  tablet1_copy%particle_x = tablet1_orig%particle_x
  tablet1_copy%label      = tablet1_orig%label
  tablet1_copy%expt       = tablet1_orig%expt
  tablet1_copy%xmax       = tablet1_orig%xmax
  tablet1_copy%xmin       = tablet1_orig%xmin
  tablet1_copy%sep        = tablet1_orig%sep
  tablet1_copy%deltax     = tablet1_orig%deltax
 
 end subroutine copy_type1
 !***********************************************************
 function t1elementnumberfromid(t1,id)
  !--------------------------------------input
  type(table1), intent(in) :: t1(:)
  integer, intent(in) :: id
  !-----------------------------------function
  integer :: t1elementnumberfromid
  !-----------------------------------internal
  integer :: n,x
  !-------------------------------------------

  n=0
  do x=lbound(t1,dim=1),ubound(t1,dim=1)
   if(t1(x)%id.eq.id)then
    n=n+1
    t1elementnumberfromid=x
   endif
  enddo

  if(n.ne.1)stop'problem in function t3elementnumberfromid 1'

 end function t1elementnumberfromid

 !************************************************************ 
 subroutine initializetables1(S95_t1)
 !***********************************************************  
 ! fills S95_t1
 !*********************************************************** 
  use store_pathname
  use usefulbits, only: Hneut,Hplus,file_id_common2
  implicit none

  !--------------------------------------input
  type(table1) :: S95_t1(:)
  !-----------------------------------internal
  logical :: newtables
  integer :: x,xbeg,xend      
  character(len=100),allocatable :: filename(:)
  character(LEN=pathname_length+150) :: fullfilename    
  integer :: col
  integer :: ios
  !-------------------------------------------  
  
  xbeg=lbound(S95_t1,dim=1)
  xend=ubound(S95_t1,dim=1)
  
  allocate(filename(xbeg:xend))    
  x=xbeg-1

  !instead, could read in the values of xmin,xmax,sep from the
  !files, but it's kinda nice having them all here to refer to

  newtables=.True.  ! i.e. use the recommended LEP single Higgs tables
  if(newtables)then   
   x=x+1
   S95_t1(x)%id=142
   S95_t1(x)%particle_x=Hneut
   S95_t1(x)%expt='LEP'                        
   S95_t1(x)%label='hep-ex/0602042, table 14b (LEP)' ! table 14b
   S95_t1(x)%xmin=12.0D0
   S95_t1(x)%xmax=120.0D0
   S95_t1(x)%sep=0.5D0
   filename(x)='lep210_hbb'
  
   x=x+1
   S95_t1(x)%id=143
   S95_t1(x)%particle_x=Hneut
   S95_t1(x)%expt='LEP'            
   S95_t1(x)%label='hep-ex/0602042, table 14c (LEP)' ! table 14c
   S95_t1(x)%xmin=4.0D0
   S95_t1(x)%xmax=120.0D0
   S95_t1(x)%sep=0.5D0      
   filename(x)='lep210_htt_interpol'
  else
   write(*,*)'WARNING: using old LEP tables' 
   x=x+1
   S95_t1(x)%id=142
   S95_t1(x)%particle_x=Hneut
   S95_t1(x)%expt='LEP'            
   S95_t1(x)%label='LEP table 14b' ! table 14b
   S95_t1(x)%xmin=1.0D0
   S95_t1(x)%xmax=140.0D0
   S95_t1(x)%sep=0.1D0
   filename(x)='old-s95_h2z_bbz'
  
   x=x+1
   S95_t1(x)%id=143 
   S95_t1(x)%particle_x=Hneut
   S95_t1(x)%expt='LEP'    
   S95_t1(x)%label='LEP table 14c' ! table 14c
   S95_t1(x)%xmin=1.0D0
   S95_t1(x)%xmax=140.0D0
   S95_t1(x)%sep=0.1D0
   filename(x)='old-s95_h2z_ttz'  
  endif

  x=x+1
  S95_t1(x)%id=300 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0206022 (OPAL)' 
  S95_t1(x)%xmin=1.0D0
  S95_t1(x)%xmax=100.0D0
  S95_t1(x)%sep=1.0D0
  filename(x)='lep_decaymodeindep'  

  x=x+1
  S95_t1(x)%id=400 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0107032v1 (LEP)' 
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=118.0D0
  S95_t1(x)%sep=1.0D0
  filename(x)='LEP_h-invisible'  

  x=x+1
  S95_t1(x)%id=500 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='LHWG Note 2002-02' 
  S95_t1(x)%xmin=20.0D0
  S95_t1(x)%xmax=116.0D0
  S95_t1(x)%sep=2.0D0
  filename(x)='LEP_h-gammagamma'  

  x=x+1
  S95_t1(x)%id=600 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='LHWG (unpublished)'!uses hep-ex/0510022,hep-ex/0205055,hep-ex/0312042,hep-ex/0408097 
  S95_t1(x)%xmin=20.0D0
  S95_t1(x)%xmax=128.6D0
  S95_t1(x)%sep=0.1D0
  filename(x)='LEP_h-2jets' 

  x=x+1
  S95_t1(x)%id=711 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0410017 (DELPHI)' 
  S95_t1(x)%xmin=12.0D0
  S95_t1(x)%xmax=50.0D0
  S95_t1(x)%sep=1.0D0
  filename(x)='Delphi_yuk_h_bbbb'  

  x=x+1
  S95_t1(x)%id=713 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0410017 (DELPHI)' 
  S95_t1(x)%xmin=12.0D0
  S95_t1(x)%xmax=50.0D0
  S95_t1(x)%sep=1.0D0
  filename(x)='Delphi_yuk_a_bbbb'  

  x=x+1
  S95_t1(x)%id=721 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0410017 (DELPHI)' 
  S95_t1(x)%xmin=4.0D0
  S95_t1(x)%xmax=50.0D0
  S95_t1(x)%sep=1.0D0
  filename(x)='Delphi_yuk_h_bbtautau'  

  x=x+1
  S95_t1(x)%id=741 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0111010 (OPAL)' 
  S95_t1(x)%xmin=4.0D0
  S95_t1(x)%xmax=12.0D0
  S95_t1(x)%sep=1.0D0
  filename(x)='OPAL_yuk_h_bbtautau' 

  x=x+1
  S95_t1(x)%id=723 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0410017 (DELPHI)' 
  S95_t1(x)%xmin=4.0D0
  S95_t1(x)%xmax=50.0D0
  S95_t1(x)%sep=1.0D0
  filename(x)='Delphi_yuk_a_bbtautau' 

  x=x+1
  S95_t1(x)%id=743 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0111010 (OPAL)' 
  S95_t1(x)%xmin=4.0D0
  S95_t1(x)%xmax=12.0D0
  S95_t1(x)%sep=1.0D0
  filename(x)='OPAL_yuk_a_bbtautau' 

  x=x+1
  S95_t1(x)%id=731 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0410017 (DELPHI)' 
  S95_t1(x)%xmin=4.0D0
  S95_t1(x)%xmax=27.0D0
  S95_t1(x)%sep=1.0D0
  filename(x)='Delphi_yuk_h_tautautautau' 

  x=x+1
  S95_t1(x)%id=733 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0410017 (DELPHI)' 
  S95_t1(x)%xmin=4.0D0
  S95_t1(x)%xmax=26.0D0
  S95_t1(x)%sep=1.0D0
  filename(x)='Delphi_yuk_a_tautautautau' 

  x=x+1
  S95_t1(x)%id=402 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0401022 (Delphi)' 
  S95_t1(x)%xmin=40.0D0
  S95_t1(x)%xmax=114.0D0
  S95_t1(x)%sep=2.0D0
  filename(x)='Delphi_h-invisible'

  x=x+1
  S95_t1(x)%id=403 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='hep-ex/0501033 (L3)' 
  S95_t1(x)%xmin=50.0D0
  S95_t1(x)%xmax=110.0D0
  S95_t1(x)%sep=5.0D0
  filename(x)='L3_h-invisible' 

  x=x+1
  S95_t1(x)%id=401 
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='LEP'    
  S95_t1(x)%label='[hep-ex] arXiv:0707.0373 (OPAL)' 
  S95_t1(x)%xmin=5.0D0
  S95_t1(x)%xmax=115.0D0
  S95_t1(x)%sep=5.0D0
  filename(x)='OPAL_h-invisible'

  !x=x+1 
  !S95_t1(x)%id=803
  !S95_t1(x)%particle_x=Hplus
  !S95_t1(x)%expt='LEP'
  !S95_t1(x)%label='[hep-ex] arxiv:0812.0267 (OPAL)'
  !S95_t1(x)%xmin=50.0D0
  !S95_t1(x)%xmax=93.0D0
  !S95_t1(x)%sep=1.0D0 
  !filename(x)='OPAL_HpHm_taunutaunu'

  !x=x+1 
  !S95_t1(x)%id=802
  !S95_t1(x)%particle_x=Hplus
  !S95_t1(x)%expt='LEP'
  !S95_t1(x)%label='[hep-ex] arxiv:0812.0267 (OPAL)'
  !S95_t1(x)%xmin=50.0D0
  !S95_t1(x)%xmax=93.0D0
  !S95_t1(x)%sep=1.0D0 
  !filename(x)='OPAL_HpHm_qqtaunu'

  !x=x+1 
  !S95_t1(x)%id=801
  !S95_t1(x)%particle_x=Hplus
  !S95_t1(x)%expt='LEP'
  !S95_t1(x)%label='[hep-ex] arxiv:0812.0267 (OPAL)'
  !S95_t1(x)%xmin=50.0D0
  !S95_t1(x)%xmax=93.0D0
  !S95_t1(x)%sep=1.0D0 
  !filename(x)='OPAL_HpHm_qqqq'

  x=x+1 
  S95_t1(x)%id=821
  S95_t1(x)%particle_x=Hplus
  S95_t1(x)%expt='LEP'
  S95_t1(x)%label='hep-ex/0107031 (LHWG)'
  S95_t1(x)%xmin=60.0D0
  S95_t1(x)%xmax=90.0D0
  S95_t1(x)%sep=1.0D0 
  filename(x)='LEP_HpHm_qqqq'

  x=x+1 
  S95_t1(x)%id=811
  S95_t1(x)%particle_x=Hplus
  S95_t1(x)%expt='LEP'
  S95_t1(x)%label='hep-ex/0404012 (Delphi)'
  S95_t1(x)%xmin=52.0D0
  S95_t1(x)%xmax=94.0D0
  S95_t1(x)%sep=2.0D0 
  filename(x)='Delphi_HpHm_qqqq'

  x=x+1 
  S95_t1(x)%id=813
  S95_t1(x)%particle_x=Hplus
  S95_t1(x)%expt='LEP'
  S95_t1(x)%label='hep-ex/0404012 (Delphi)'
  S95_t1(x)%xmin=52.0D0
  S95_t1(x)%xmax=94.0D0
  S95_t1(x)%sep=2.0D0 
  filename(x)='Delphi_HpHm_taunutaunu'

!-------------------BEGIN NEW TEVATRON SEARCHES-(HB3.0)-----------------
  x=x+1 
  S95_t1(x)%id=7712
  S95_t1(x)%particle_x=Hplus
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 7712'
  S95_t1(x)%xmin=80.0D0
  S95_t1(x)%xmax=160.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_t-Hplusb_tauonicHM_192pb_7712'

  x=x+1 
  S95_t1(x)%id=3233
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='TCB'
  S95_t1(x)%label='[hep-ex] arXiv:1103.3233v2 (TEVNPHWG)' !CDF Note 10432, D0 Note 6183
  S95_t1(x)%xmin=130.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_D0_SM_combined_4.3-8.2fb_3233_CLs'
  filename(x)='CDF_D0_SM_combined_4.3-8.2fb_3233_bayesian'

  x=x+1
  S95_t1(x)%id=6183
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 6183'
  S95_t1(x)%xmin=130.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0
  S95_t1(x)%deltax=0.0D0  
  filename(x)='D0_SM_combined_6183'

  x=x+1
  S95_t1(x)%id=6171
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 6171'
  S95_t1(x)%xmin=105.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0                        
  filename(x)='D0_H-tautaujj-4.3fb_6171'

  x=x+1
  S95_t1(x)%id=10439
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 10439'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_H-tautau_6.0fb_10439'

  x=x+1
  S95_t1(x)%id=10433
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 10432'
  S95_t1(x)%xmin=110.0D0
  S95_t1(x)%xmax=300.0D0
  S95_t1(x)%sep=5.0D0 
  filename(x)='CDF_ggH-WW_7.1fb_10433_SMnormalized'
  
  x=x+1 
  S95_t1(x)%id=10432
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 10432'
  S95_t1(x)%xmin=110.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_H-WW_7.1fb_10432'  

  x=x+1 
  S95_t1(x)%id=5974
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 5974'
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=300.0D0
  S95_t1(x)%sep=10.0D0  
  filename(x)='D0_Hb_tautaub_3.7fb_5974' 
  
  x=x+1 
  S95_t1(x)%id=6170
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 6170'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0   
  filename(x)='D0_ZH_bb_6.2fb_6170' 

  x=x+1 
  S95_t1(x)%id=6182
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 6182'
  S95_t1(x)%xmin=115.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0   
  filename(x)='D0_H-VV_8.1fb_6182' 

  x=x+1 
  S95_t1(x)%id=6179
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 6179'
  S95_t1(x)%xmin=115.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0   
  filename(x)='D0_H-WW-mutau_7.3fb_6179' 

  x=x+1 
  S95_t1(x)%id=6177
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 6177'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=2.5D0 
  S95_t1(x)%deltax=0.0D0   
  filename(x)='D0_gaga_8.2fb_6177' 

  x=x+1 
  S95_t1(x)%id=10485
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 10485' 
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_SM_Hgaga_7.0fb_10485' 
!-------------------END NEW TEVATRON SEARCHES---------------------------

  x=x+1 
  S95_t1(x)%id=10235 
  S95_t1(x)%particle_x=Hneut 
  S95_t1(x)%expt='CDF' 
  S95_t1(x)%label='CDF Note 10235' 
  S95_t1(x)%xmin=100.0D0  
  S95_t1(x)%xmax=150.0D0 
  S95_t1(x)%sep=5.0D0  
  filename(x)='CDF_ZH_llbb_5.7fb_10235' 

  x=x+1 
  S95_t1(x)%id=3047
  S95_t1(x)%particle_x=Hneut 
  S95_t1(x)%expt='CDF' 
  S95_t1(x)%label='[hep-ex] arXiv:1009.3047 (CDF)' 
  S95_t1(x)%xmin=100.0D0  
  S95_t1(x)%xmax=150.0D0 
  S95_t1(x)%sep=5.0D0  
  filename(x)='CDF_ZH_llbb_4.1fb_3047' 

  x=x+1 
  S95_t1(x)%id=6089
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 6089'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  filename(x)='D0_ZH_llbb_6.2fb_6089' 

  x=x+1 
  S95_t1(x)%id=3564
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:1008.3564 (D0)'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  filename(x)='D0_ZH_llbb_4.2fb_3564' 

  x=x+1 
  S95_t1(x)%id=10212
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 10212'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_VH_Metbb_5.7fb_10212'

  x=x+1 
  S95_t1(x)%id=6087
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 6087'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_VH_bb_6.4fb_6087'

  x=x+1 
  S95_t1(x)%id=3935
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='[hep-ex] arXiv:0911.3935v4 (CDF)'
  S95_t1(x)%xmin=110.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_VH_Metbb_2.1fb_3935_interpol'

  x=x+1 
  S95_t1(x)%id=5285
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:0912.5285 (D0)'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_VH_bb_5.2fb_5285'

  x=x+1 
  S95_t1(x)%id=6092
  S95_t1(x)%particle_x=Hneut 
  S95_t1(x)%expt=' D0' 
  S95_t1(x)%label='D0 Note 6092'!this is what the note says, but the website says 6082 
  S95_t1(x)%xmin=100.0D0  
  S95_t1(x)%xmax=150.0D0 
  S95_t1(x)%sep=5.0D0  
  filename(x)='D0_WH_lnubb_5.3fb_6092' 

  x=x+1 
  S95_t1(x)%id=10239
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 10239' 
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  filename(x)='CDF_WH_lnubb_5.7fb_10239' 

  x=x+1 
  S95_t1(x)%id=0874
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:1012.0874 (D0)'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  filename(x)='D0_WH_lnubb_5.3fb_0874'

  x=x+1 
  S95_t1(x)%id=5613 
  S95_t1(x)%particle_x=Hneut 
  S95_t1(x)%expt='CDF' 
  S95_t1(x)%label='[hep-ex] arXiv:0906.5613 (CDF)' 
  S95_t1(x)%xmin=100.0D0  
  S95_t1(x)%xmax=150.0D0 
  S95_t1(x)%sep=5.0D0  
  filename(x)='CDF_WH_lnubb_2.7fb_5613'

  x=x+1 
  S95_t1(x)%id=5757
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 5757' 
  S95_t1(x)%xmin=115.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_ppH_WW_ll_3.0fb_5757' 

  x=x+1 
  S95_t1(x)%id=3930
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='[hep-ex] arXiv:0809.3930 (CDF)' 
  S95_t1(x)%xmin=110.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='CDF_ggH_WW_3.0fb_3930'
 
  x=x+1
  S95_t1(x)%id=3216
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='TCB'
  S95_t1(x)%label='[hep-ex] arXiv:1005.3216 (TEVNPHWG)'
  S95_t1(x)%xmin=110.0D0
  S95_t1(x)%xmax=300.0D0
  S95_t1(x)%sep=5.0D0 
  filename(x)='CDF_D0_combined_gg-H-WW_4.8-5.4fb_3216_bayesian_interpol'

  !x=x+1 
  !S95_t1(x)%id=10102
  !S95_t1(x)%particle_x=Hneut 
  !S95_t1(x)%expt='CDF' 
  !S95_t1(x)%label='CDF Note 10102' 
  !S95_t1(x)%xmin=110.0D0  
  !S95_t1(x)%xmax=200.0D0 
  !S95_t1(x)%sep=5.0D0  
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_H-WW_5.3fb_10102' 

  x=x+1 
  S95_t1(x)%id=4468 
  S95_t1(x)%particle_x=Hneut 
  S95_t1(x)%expt='CDF' 
  S95_t1(x)%label='[hep-ex] arXiv:1001.4468 (CDF)' 
  S95_t1(x)%xmin=110.0D0  
  S95_t1(x)%xmax=200.0D0 
  S95_t1(x)%sep=5.0D0  
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_H-WW_4.8fb_4468_interpol' 

  x=x+1 
  S95_t1(x)%id=5871
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 5871'
  S95_t1(x)%xmin=115.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_H-WW_llnunu_4.2fb_5871'

  !x=x+1 
  !S95_t1(x)%id=6082
  !S95_t1(x)%particle_x=Hneut 
  !S95_t1(x)%expt=' D0' 
  !S95_t1(x)%label='D0 Note 6082'
  !S95_t1(x)%xmin=115.0D0  
  !S95_t1(x)%xmax=200.0D0 
  !S95_t1(x)%sep=5.0D0  
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='D0_H-VV_6.7fb_6082' 

  x=x+1 
  S95_t1(x)%id=4481
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:1001.4481 (D0)'
  S95_t1(x)%xmin=115.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_H-WW_5.4fb_4481' 

  x=x+1 
  S95_t1(x)%id=4162
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='TCB'
  S95_t1(x)%label='[hep-ex] arXiv:1001.4162 (TEVNPHWG)'
  S95_t1(x)%xmin=130.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_D0_SM_combined_H-WW_4.8-5.4fb_4162'

  x=x+1 
  S95_t1(x)%id=8961
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='TCB'
  S95_t1(x)%label='[hep-ex] arXiv:0712.2383v1(TEVNPHWG)' !CDF Note 8961, D0 Note 5536
  S95_t1(x)%xmin=110.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_D0_SM_combined_1.0-1.9fb_8961-5536_interpol'

  !x=x+1 
  !S95_t1(x)%id=10133
  !S95_t1(x)%particle_x=Hneut 
  !S95_t1(x)%expt='CDF' 
  !S95_t1(x)%label='CDF Note 10133' 
  !S95_t1(x)%xmin=100.0D0  
  !S95_t1(x)%xmax=150.0D0 
  !S95_t1(x)%sep=5.0D0
  !S95_t1(x)%deltax=0.0D0   
  !filename(x)='CDF_H-tautau_2.3fb_10133'

  x=x+1 
  S95_t1(x)%id=4800
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:0903.4800 (D0)'
  S95_t1(x)%xmin=105.0D0
  S95_t1(x)%xmax=145.0D0
  S95_t1(x)%sep=10.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_SM_tautau_1.0fb_4800'

  x=x+1 
  S95_t1(x)%id=5845
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 5845'
  S95_t1(x)%xmin=105.0D0
  S95_t1(x)%xmax=145.0D0
  S95_t1(x)%sep=10.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_tautauqq_4.9fb_5845'

  x=x+1 
  S95_t1(x)%id=9290
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='TCB'
  S95_t1(x)%label='[hep-ex] arXiv:0804.3423(TEVNPHWG)' !CDF Note 9290, D0 Note 5645
  S95_t1(x)%xmin=110.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_D0_SM_combined_1.0-2.4fb_9290-5645_interpol'

  x=x+1 
  S95_t1(x)%id=9465
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='TCB'
  S95_t1(x)%label='[hep-ex] arXiv:0808.0534(TEVNPHWG)' !CDF Note 9465, D0 Note 5754
  S95_t1(x)%xmin=155.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_D0_SM_combined_3.0fb_9465-5754_CLs'
  filename(x)='CDF_D0_SM_combined_3.0fb_9465-5754_bayesian'

  x=x+1 
  S95_t1(x)%id=0598
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:0712.0598v1 (D0)'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_SM_combined_0598_interpol'

  x=x+1 
  S95_t1(x)%id=9999
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 9999'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_SM_combined_2.0-4.8fb_9999_interpol'

  x=x+1 
  S95_t1(x)%id=6008
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 6008'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_SM_combined_6008'

  x=x+1 
  S95_t1(x)%id=9998
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='TCB'
  S95_t1(x)%label='[hep-ex] arXiv:0911.3930 (TEVNPHWG)'!CDF Note 9998, D0 Note 5983
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_D0_SM_combined_2.1-5.4fb_9998-5983_bayesian'

  x=x+1 
  S95_t1(x)%id=6096
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='TCB'
  S95_t1(x)%label='[hep-ex] arXiv:1007.4587 (TEVNPHWG)' !CDF Note 10241, D0 Note 6096
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_D0_SM_combined_2.1-6.7fb_10241-6096_bayesian'

  x=x+1 
  S95_t1(x)%id=10010
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 10010' 
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=10.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_hadr_4fb_10010'

  x=x+1 
  S95_t1(x)%id=10105
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 10105' 
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=210.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='CDF_bbH_bb_2.2fb_10105'

  x=x+1 
  S95_t1(x)%id=5726
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 5726' 
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=220.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='D0_bbH_bb_2.6fb_5726_sq_interpol'

  x=x+1 
  S95_t1(x)%id=1931
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:1011.1931 (D0)' 
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=300.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='D0_bbH_bb_5.2fb_1931'

  x=x+1 
  S95_t1(x)%id=2491
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:0805.2491 (D0)' 
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=300.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='D0_ppH_tautau_1fb_2491_interpol'

  x=x+1 
  S95_t1(x)%id=1014
  S95_t1(x)%particle_x=Hneut 
  S95_t1(x)%expt='CDF' 
  S95_t1(x)%label='[hep-ex] arXiv:0906.1014 (CDF)' 
  S95_t1(x)%xmin=90.0D0  
  S95_t1(x)%xmax=250.0D0 
  S95_t1(x)%sep=10.0D0  
  filename(x)='CDF_H-tautau_1.8fb_1014_interpol'

  x=x+1 
  S95_t1(x)%id=5740
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 5740'
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=300.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='D0_H-tautau_2.2fb_5740_interpol' 

  x=x+1 
  S95_t1(x)%id=3363
  S95_t1(x)%particle_x=Hneut 
  S95_t1(x)%expt='TCB' 
  S95_t1(x)%label='[hep-ex] arXiv:1003.3363 (TEVNPHWG)' 
  S95_t1(x)%xmin=90.0D0  
  S95_t1(x)%xmax=200.0D0 
  S95_t1(x)%sep=10.0D0  
  filename(x)='CDF_D0_combinedH-tautau_2.2fb_3363_CLs'

  x=x+1 
  S95_t1(x)%id=5873
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 5873'
  S95_t1(x)%xmin=120.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=20.0D0 
  filename(x)='D0_WH_WWW_llnunu_3.6fb_5873'

  x=x+1 
  S95_t1(x)%id=7307
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 7307 vs 3' 
  S95_t1(x)%xmin=110.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='CDF_WH_WWW_2.7fb_7307vs3.0'  
  !filename(x)='CDF_WH_WWW_1.9fb_7307' 

  x=x+1 
  S95_t1(x)%id=6091
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 6091'
  S95_t1(x)%xmin=115.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_VH_ll_5.4fb_6091'

  !x=x+1 
  !S95_t1(x)%id=5858
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 5858'
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=2.5D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='D0_gaga_4.2fb_5858'

  x=x+1 
  S95_t1(x)%id=1887
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:0901.1887 (D0)'
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_Hgaga_2.7fb_1887'

  x=x+1 
  S95_t1(x)%id=10065
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='CDF Note 10065' 
  S95_t1(x)%xmin=100.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=10.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_SM_Hgaga_5.4fb_10065' 

  x=x+1 
  S95_t1(x)%id=0968
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:0912.0968 (D0)'
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=320.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='D0_Hb_tautaub_2.7fb_0968'

  x=x+1 
  S95_t1(x)%id=5985
  S95_t1(x)%particle_x=Hneut 
  S95_t1(x)%expt=' D0' 
  S95_t1(x)%label='D0 Note 5985' 
  S95_t1(x)%xmin=90.0D0  
  S95_t1(x)%xmax=320.0D0 
  S95_t1(x)%sep=10.0D0  
  filename(x)='D0_bH_btautau_2.7fb_5985' 

  x=x+1 
  S95_t1(x)%id=6083
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 6083' 
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='D0_Hb_tautaub_4.3fb_6083'

  x=x+1 
  S95_t1(x)%id=5739
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='D0 Note 5739'
  S95_t1(x)%xmin=105.0D0
  S95_t1(x)%xmax=155.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='D0_ttH_ttbb_2.1fb_5739'

  x=x+1 
  S95_t1(x)%id=0611
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:0806.0611 (D0)'
  S95_t1(x)%xmin=120.0D0
  S95_t1(x)%xmax=320.0D0
  S95_t1(x)%sep=20.0D0 
  filename(x)='D0_H-Zgamma_1.0-1.1fb_0611'

  x=x+1 
  S95_t1(x)%id=1811
  S95_t1(x)%particle_x=Hplus
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:0908.1811 (D0)'
  S95_t1(x)%xmin=80.0D0
  S95_t1(x)%xmax=155.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_Hp_qq_1.0fb_1811_interpol'

  x=x+1 
  S95_t1(x)%id=1269
  S95_t1(x)%particle_x=Hplus
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='[hep-ex] arXiv:0907.1269 (CDF)'
  S95_t1(x)%xmin=60.0D0
  S95_t1(x)%xmax=70.0D0
  S95_t1(x)%sep=10.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_t-Hplusb_1269_lowmass'

  x=x+1 
  S95_t1(x)%id=1270
  S95_t1(x)%particle_x=Hplus
  S95_t1(x)%expt='CDF'
  S95_t1(x)%label='[hep-ex] arXiv:0907.1269 (CDF)'
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=150.0D0
  S95_t1(x)%sep=10.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='CDF_t-Hplusb_1269_highmass'

  x=x+1 
  S95_t1(x)%id=1812
  S95_t1(x)%particle_x=Hplus
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:0908.1811 (D0)'
  S95_t1(x)%xmin=80.0D0
  S95_t1(x)%xmax=155.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_Hp_taunu_1.0fb_1811_interpol'

  x=x+1 
  S95_t1(x)%id=2011026
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='ATL'
  S95_t1(x)%label='ATLAS-CONF-2011-026'
  S95_t1(x)%xmin=200.0D0
  S95_t1(x)%xmax=600.0D0
  S95_t1(x)%sep=20.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='2011026_Atlas_H-VV_35pb-1'

  x=x+1 
  S95_t1(x)%id=2011025
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='ATL'
  S95_t1(x)%label='ATLAS-CONF-2011-025'
  S95_t1(x)%xmin=110.0D0
  S95_t1(x)%xmax=140.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='2011025_Atlas_H-gaga_37.6pb-1_interpol'

  x=x+1 
  S95_t1(x)%id=2011005
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='ATL'
  S95_t1(x)%label='ATLAS-CONF-2011-005'
  S95_t1(x)%xmin=120.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='2011005_Atlas_H-WW_35pb-1_interpol'

  x=x+1 
  S95_t1(x)%id=2011052
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='ATL'
  S95_t1(x)%label='ATLAS-CONF-2011-052'
  S95_t1(x)%xmin=220.0D0
  S95_t1(x)%xmax=600.0D0
  S95_t1(x)%sep=20.0D0 
  filename(x)='2011052_Atlas_H-WW_35pb-1'

!-----------NEW ANALYSIS (since HB-3.1.4)----------

  x=x+1 
  S95_t1(x)%id=2011048
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='ATL'
  S95_t1(x)%label='ATLAS-CONF-2011-048'
  S95_t1(x)%xmin=120.0D0
  S95_t1(x)%xmax=600.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='2011048_Atlas_H-ZZ-4l_40pb-1_interpol'

  x=x+1 
  S95_t1(x)%id=2011085
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='ATL'
  S95_t1(x)%label='ATLAS-CONF-2011-085'
  S95_t1(x)%xmin=110.0D0
  S95_t1(x)%xmax=140.0D0
  S95_t1(x)%sep=1.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='2011085_Atlas_H-gaga_209pb-1'

  x=x+1 
  S95_t1(x)%id=2748
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='ATL'
  S95_t1(x)%label='[hep-ex] arXiv:1106.2748 (ATLAS)'
  S95_t1(x)%xmin=110.0D0
  S95_t1(x)%xmax=600.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='2748_Atlas_SMcombined_40pb-1'

  x=x+1 
  S95_t1(x)%id=1268
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:1107.1268 (D0)'
  S95_t1(x)%xmin=115.0D0
  S95_t1(x)%xmax=200.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='D0_VH_ll_5.3fb_1268'
  
  x=x+1 
  S95_t1(x)%id=4555
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:1106.4555 (D0)'
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=300.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='D0_H-tautau_5.4fb_4555_interpol' 
  
  x=x+1 
  S95_t1(x)%id=4885
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt=' D0'
  S95_t1(x)%label='[hep-ex] arXiv:1106.4885 (D0)'
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=320.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='D0_Hb_tautaub_7.3fb_4885'
  
!---------END NEW ANALYSIS (since HB-3.1.4)---------

  !x=x+1 
  !S95_t1(x)%id=2011020
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='ATL'
  !S95_t1(x)%label='ATLAS-CONF-2011-020'
  !S95_t1(x)%xmin=6.1D0
  !S95_t1(x)%xmax=9.0D0
  !S95_t1(x)%sep=0.1D0 
  !filename(x)='2011020_Atlas_H-mumu_lowerMa_35pb-1'

  !x=x+1 
  !S95_t1(x)%id=2011021
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='ATL'
  !S95_t1(x)%label='ATLAS-CONF-2011-020'
  !S95_t1(x)%xmin=11.0D0
  !S95_t1(x)%xmax=11.9D0
  !S95_t1(x)%sep=0.1D0 
  !filename(x)='2011021_Atlas_H-mumu_higherMa_35pb-1'

  x=x+1 
  S95_t1(x)%id=5429
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CMS'
  S95_t1(x)%label='[hep-ex] arXiv: 1102.5429(CMS)'
  S95_t1(x)%xmin=130.0D0
  S95_t1(x)%xmax=400.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='5429_CMS_H-WW_36pb-1_rat_interpol'

  x=x+1 
  S95_t1(x)%id=10002
  S95_t1(x)%particle_x=Hneut
  S95_t1(x)%expt='CMS'
  S95_t1(x)%label='[hep-ex] arXiv: 1104:1619(CMS)'!CMS PAS HIG-10-002
  S95_t1(x)%xmin=90.0D0
  S95_t1(x)%xmax=500.0D0
  S95_t1(x)%sep=10.0D0 
  filename(x)='10002_CMS_H-tautau_36pb-1_interpol'

  x=x+1 
  S95_t1(x)%id=11002
  S95_t1(x)%particle_x=Hplus
  S95_t1(x)%expt='CMS'
  S95_t1(x)%label='CMS PAS HIG-11-002'
  S95_t1(x)%xmin=80.0D0
  S95_t1(x)%xmax=160.0D0
  S95_t1(x)%sep=5.0D0 
  S95_t1(x)%deltax=0.0D0 
  filename(x)='11002_CMS_t-Hplusb_36pb-1'


!&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
!   superceded

  !x=x+1     !superseded by arXiv:1011.1931
  !S95_t1(x)%id=3556
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='[hep-ex] arXiv:0805.3556 (D0)' 
  !S95_t1(x)%xmin=90.0D0
  !S95_t1(x)%xmax=220.0D0
  !S95_t1(x)%sep=10.0D0 
  !filename(x)='D0_bbH_bb_1.0fb_3556_interpol'

  !x=x+1     !superseded by arXiv:1009.3047
  !S95_t1(x)%id=3534
  !S95_t1(x)%particle_x=Hneut 
  !S95_t1(x)%expt='CDF' 
  !S95_t1(x)%label='[hep-ex] arXiv:0908.3534 (CDF)' 
  !S95_t1(x)%xmin=100.0D0  
  !S95_t1(x)%xmax=150.0D0 
  !S95_t1(x)%sep=5.0D0  
  !filename(x)='CDF_ZH_llbb_2.7fb_3534' 

  !x=x+1    !superseded by CDF 10239
  !S95_t1(x)%id=10217
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 10217' 
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='CDF_WH_lnubb_5.6fb_10217' 

  !x=x+1   !superseded by CDF Note 10133
  !S95_t1(x)%id=9248
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9248' 
  !S95_t1(x)%xmin=110.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_SMcomb_tautau_2.0fb_9248_interpol'

  !x=x+1  !superseded by arXiv:1012.0874
  !S95_t1(x)%id=1970
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='[hep-ex] arXiv:0808.1970 (D0)'
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='D0_WH_lnubb_1.05fb_1970'

  !x=x+1 
  !S95_t1(x)%id=6095   
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 6095'
  !S95_t1(x)%xmin=115.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=5.0D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='D0_H-WW_lljj_5.4fb_6095'

  !x=x+1 
  !S95_t1(x)%id=5972 
  !S95_t1(x)%particle_x=Hneut 
  !S95_t1(x)%expt=' D0' 
  !S95_t1(x)%label='D0 Note 5972' 
  !S95_t1(x)%xmin=100.0D0  
  !S95_t1(x)%xmax=150.0D0 
  !S95_t1(x)%sep=5.0D0  
  !filename(x)='D0_WH_lnubb_5.0fb_5972'

  !x=x+1 
  !S95_t1(x)%id=10068
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 10068' 
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='CDF_WH_lnubb_4.8fb_10068'

  !x=x+1
  !S95_t1(x)%id=5586
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 5586' 
  !S95_t1(x)%xmin=105.0D0
  !S95_t1(x)%xmax=145.0D0
  !S95_t1(x)%sep=10.0D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='D0_ZH_nunubb_2.1fb_5586'

  !x=x+1 
  !S95_t1(x)%id=9891
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9891'
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_VH_Metbb_3.6fb_9891'

  !x=x+1 
  !S95_t1(x)%id=5876
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 5876'
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='D0_ZH_llbb_4.2fb_5876'

  !x=x+1 
  !S95_t1(x)%id=9889 
  !S95_t1(x)%particle_x=Hneut 
  !S95_t1(x)%expt='CDF' 
  !S95_t1(x)%label='CDF Note 9889' 
  !S95_t1(x)%xmin=100.0D0  
  !S95_t1(x)%xmax=150.0D0 
  !S95_t1(x)%sep=5.0D0  
  !filename(x)='CDF_ZH_llbb_4.1fb_9889' 

  !x=x+1 
  !S95_t1(x)%id=9284
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9284' 
  !S95_t1(x)%xmin=90.0D0
  !S95_t1(x)%xmax=210.0D0
  !S95_t1(x)%sep=10.0D0 
  !filename(x)='CDF_bbH_bb_1.9fb_9284'

  !x=x+1 
  !S95_t1(x)%id=9868
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9868' 
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='CDF_WH_lnubb_4.3fb_9868' !http://www-cdf.fnal.gov/physics/new/hdg/results/whlnubb_090814/WH4.3fb.html

  !x=x+1 
  !S95_t1(x)%id=9887 !superseded by arXiv:1001.4468
  !S95_t1(x)%particle_x=Hneut 
  !S95_t1(x)%expt='CDF' 
  !S95_t1(x)%label='CDF Note 9887' 
  !S95_t1(x)%xmin=110.0D0  
  !S95_t1(x)%xmax=200.0D0 
  !S95_t1(x)%sep=5.0D0  
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_H-WW_4.8fb_9887_interpol' 

  !x=x+1 
  !S95_t1(x)%id=0024
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='[hep-ex] arXiv:0811.0024v1 (D0)'
  !S95_t1(x)%xmin=90.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=10.0D0 
  !filename(x)='D0_bH_btautau_328pb_0024'

  !x=x+1 
  !S95_t1(x)%id=1266
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='[hep-ex] arXiv:0808.1266 (D0)'
  !S95_t1(x)%xmin=105.0D0
  !S95_t1(x)%xmax=135.0D0
  !S95_t1(x)%sep=10.0D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='D0_VH_bb_0.93fb_1266'

  !x=x+1 
  !S95_t1(x)%id=0432
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='[hep-ex] arXiv:0802.0432 (CDF)'
  !S95_t1(x)%xmin=110.0D0
  !S95_t1(x)%xmax=140.0D0
  !S95_t1(x)%sep=5.0D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_VH_Metbb_1fb_0432'

  !x=x+1 
  !S95_t1(x)%id=9674
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9674'
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=5.0D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_SM_combined_2.0-3.0fb_9674_interpol'

  !x=x+1 
  !S95_t1(x)%id=5980
  !S95_t1(x)%particle_x=Hneut 
  !S95_t1(x)%expt='TCB' 
  !S95_t1(x)%label='D0 Note 5980, CDF Note 9888' 
  !S95_t1(x)%xmin=100.0D0  
  !S95_t1(x)%xmax=200.0D0 
  !S95_t1(x)%sep=10.0D0  
  !filename(x)='CDF_D0_combinedH-tautau_2.2fb_5980' 

  !x=x+1 
  !S95_t1(x)%id=9714
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='TCB'
  !S95_t1(x)%label='arXiv:0903.4001 (TEVNPHWG), MH>=155GeV'!CDF Note 9713, D0 Note 5889
  !S95_t1(x)%xmin=155.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=5.0D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_D0_SM_combined_4.2fb_9713-5889_bayesian_highmassonly'

  !x=x+1 
  !S95_t1(x)%id=9897
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9897'
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=5.0D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_SM_combined_2.0-4.8fb_9897_interpol'

  !x=x+1 
  !S95_t1(x)%id=8742
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'                        
  !S95_t1(x)%label='CDF Note 8742' ! table from CDF note 8742
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0
  !filename(x)='CDF_ZH_llbb_1fb_8742_interpol' 
  
!   x=x+1
!   S95_t1(x)%id=7081
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt='CDF'
!   S95_t1(x)%label='arxiv 070810 (CDF)'
!   S95_t1(x)%xmin=110.0D0
!   S95_t1(x)%xmax=150.0D0
!   S95_t1(x)%sep=5.0D0
!     S95_t1(x)%deltax=0.0D0 
!   filename(x)='CDF_ZH_nunubb_1.7fb_070810_interpol'
  
! !   x=x+1
! !   S95_t1(x)%id=8958 
! !   S95_t1(x)%particle_x=Hneut
! !   S95_t1(x)%expt='CDF' 
! !   S95_t1(x)%label='CDF Note 8958' 
! !   S95_t1(x)%xmin=110.0D0
! !   S95_t1(x)%xmax=200.0D0
! !   S95_t1(x)%sep=10.0D0
! !   filename(x)='CDF_ggH_WW_1.9fb_8958' 
   
!   x=x+1
!   S95_t1(x)%id=8957
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt='CDF'
!   S95_t1(x)%label='CDF Note 8957' 
!   S95_t1(x)%xmin=110.0D0
!   S95_t1(x)%xmax=150.0D0
!   S95_t1(x)%sep=5.0D0
!   filename(x)='CDF_WH_lnubb_1.7fb_8957_interpol'

!   x=x+1
!   S95_t1(x)%id=5489
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt=' D0'
!   S95_t1(x)%label='D0 Note 5489' 
!   S95_t1(x)%xmin=120.0D0
!   S95_t1(x)%xmax=200.0D0
!   S95_t1(x)%sep=20.0D0
!   filename(x)='D0_ppH_WW_emu_0.6fb_5489'
  
  !x=x+1
  !S95_t1(x)%id=5537
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 5537' 
  !S95_t1(x)%xmin=120.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=20.0D0
  !filename(x)='D0_ppH_WW_ll_1.7fb_5537'
  
!   x=x+1
!   S95_t1(x)%id=5482
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt=' D0'
!   S95_t1(x)%label='D0 Note 5482' 
!   S95_t1(x)%xmin=105.0D0
!   S95_t1(x)%xmax=145.0D0
!   S95_t1(x)%sep=10.0D0 
!   filename(x)='D0_ZH_llbb_1.1fb_5482' 
 
!   x=x+1 
!   S95_t1(x)%id=5624
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt=' D0'
!   S95_t1(x)%label='D0 Note 5624' 
!   S95_t1(x)%xmin=115.0D0
!   S95_t1(x)%xmax=200.0D0
!   S95_t1(x)%sep=5.0D0 
!   filename(x)='D0_ppH_WW_ll_2.3fb_5624'

  !x=x+1 
  !S95_t1(x)%id=5472
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 5472' 
  !S95_t1(x)%xmin=105.0D0
  !S95_t1(x)%xmax=145.0D0
  !S95_t1(x)%sep=10.0D0 
  !!filename(x)='D0_WH_lnubb_1.7fb_5472' 
  !filename(x)='D0_WH_lnubb_1.7fb_5472_Fig.6a'
  
  !x=x+1 
  !S95_t1(x)%id=5502
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 5502' 
  !S95_t1(x)%xmin=120.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=20.0D0 
  !filename(x)='D0_ppH_WW_ee_0.6fb_5502'  

  !x=x+1 
  !S95_t1(x)%id=5332
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 5332' 
  !S95_t1(x)%xmin=120.0D0
  !S95_t1(x)%xmax=180.0D0
  !S95_t1(x)%sep=20.0D0 
  !filename(x)='D0_ppH_WW_mutau_1fb_5332' 
  
  !x=x+1 
  !S95_t1(x)%id=5485
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 5485' 
  !S95_t1(x)%xmin=120.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=20.0D0 
  !filename(x)='D0_WH_WWW_llnunu_1fb_5485'

  !x=x+1 
  !S95_t1(x)%id=9071
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9071' 
  !S95_t1(x)%xmin=90.0D0
  !S95_t1(x)%xmax=250.0D0
  !S95_t1(x)%sep=10.0D0 
  !filename(x)='CDF_ppH_tautau_1.8fb_9071_interpol'

  !x=x+1 
  !S95_t1(x)%id=5331
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 5331' 
  !S95_t1(x)%xmin=90.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=10.0D0 
  !filename(x)='D0_ppH_tautau_1fb_5331_interpol'

!   x=x+1 
!   S95_t1(x)%id=5503
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt=' D0'
!   S95_t1(x)%label='D0 Note 5503' 
!   S95_t1(x)%xmin=100.0D0
!   S95_t1(x)%xmax=170.0D0
!   S95_t1(x)%sep=10.0D0 
!   filename(x)='D0_bbH_bb_0.9fb_5503_interpol'

  !x=x+1 
  !S95_t1(x)%id=8954
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 8954' 
  !S95_t1(x)%xmin=90.0D0
  !S95_t1(x)%xmax=210.0D0
  !S95_t1(x)%sep=10.0D0 
  !filename(x)='CDF_bbH_bb_1fb_8954'

!   x=x+1 
!   S95_t1(x)%id=9236
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt='CDF'
!   S95_t1(x)%label='CDF Note 9236' 
!   S95_t1(x)%xmin=110.0D0
!   S95_t1(x)%xmax=200.0D0
!   S95_t1(x)%sep=10.0D0 
!   filename(x)='CDF_ggH_WW_2.4fb_9236'

!   x=x+1 
!   S95_t1(x)%id=9219
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt='CDF'
!   S95_t1(x)%label='CDF Note 9219' 
!   S95_t1(x)%xmin=110.0D0
!   S95_t1(x)%xmax=150.0D0
!   S95_t1(x)%sep=5.0D0 
!   filename(x)='CDF_WH_lnubb_1.9fb_9219'    

!   x=x+1 
!   S95_t1(x)%id=5601
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt=' D0'
!   S95_t1(x)%label='D0 Note 5601' 
!   S95_t1(x)%xmin=100.0D0
!   S95_t1(x)%xmax=150.0D0
!   S95_t1(x)%sep=10.0D0 
!   filename(x)='D0_Hgaga_2.27fb_5601'

  !taken out until we sort out a fermiophobic-ness test
  !x=x+1 
  !S95_t1(x)%id=1514
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='[hep-ex] arXiv:0803.1514v1 (D0)' 
  !S95_t1(x)%xmin=70.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=10.0D0 
  !filename(x)='D0_gaga_1.1fb_1514'
 
  
!   x=x+1 
!   S95_t1(x)%id=9166
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt='CDF'
!   S95_t1(x)%label='CDF Note 9166' 
!   S95_t1(x)%xmin=110.0D0
!   S95_t1(x)%xmax=150.0D0
!   S95_t1(x)%sep=5.0D0 
!    S95_t1(x)%deltax=0.0D0 
!   filename(x)='CDF_VH_Metbb_1.97fb_9166_interpol'  

  !x=x+1 
  !S95_t1(x)%id=9463
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9463' 
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='CDF_WH_lnubb_2.7fb_9463'

  !x=x+1 
  !S95_t1(x)%id=5570
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 5570' 
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='D0_ZH_llbb_2.3fb_5570'

  !x=x+1 
  !S95_t1(x)%id=4493
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='[hep-ex] arXiv:0807.4493 (CDF)' 
  !S95_t1(x)%xmin=110.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='CDF_ZH_llbb_1fb_4493_interpol'

  !x=x+1 
  !S95_t1(x)%id=9475
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9475' 
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='CDF_ZH_llbb_2.4fb_9475'

  !x=x+1 
  !S95_t1(x)%id=5737
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 5737'
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='D0_gaga_2.68fb_5737'

  !x=x+1
  !S95_t1(x)%id=9483
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF note 9483'
  !S95_t1(x)%xmin=105.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_VH_Metbb_2.1fb_9483'

  !x=x+1 
  !S95_t1(x)%id=9500
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9500'
  !S95_t1(x)%xmin=110.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='CDF_ggH_WW_3.0fb_9500_interpol'


  !x=x+1 
  !S95_t1(x)%id=9713
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='TCB'
  !S95_t1(x)%label='CDF Note 9713, D0 Note 5889'
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='CDF_D0_SM_combined_4.2fb_9713-5889_bayesian'

!   x=x+1 
!   S95_t1(x)%id=1024
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt='CDF'
!   S95_t1(x)%label='CDF Note XXXX, zhllbb_081024'
!   S95_t1(x)%xmin=100.0D0
!   S95_t1(x)%xmax=150.0D0
!   S95_t1(x)%sep=5.0D0 
!   filename(x)='CDF_ZH_llbb_2.7fb_1024'

  !x=x+1 
  !S95_t1(x)%id=9596
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9596' 
  !S95_t1(x)%xmin=100.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='CDF_WH_lnubb_2.7fb_9596' 

!   x=x+1 
!   S95_t1(x)%id=5828
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt=' D0'
!   S95_t1(x)%label='D0 Note 5828'
!   S95_t1(x)%xmin=100.0D0
!   S95_t1(x)%xmax=150.0D0
!   S95_t1(x)%sep=5.0D0 
!   filename(x)='D0_WH_lnubb_2.7fb_5828'

  !x=x+1 
  !S95_t1(x)%id=9642
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9642'
  !S95_t1(x)%xmin=105.0D0
  !S95_t1(x)%xmax=150.0D0
  !S95_t1(x)%sep=5.0D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_VH_Metbb_2.1fb_9642'

!   x=x+1 
!   S95_t1(x)%id=9022
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt='CDF'
!   S95_t1(x)%label='CDF Note 9764,"old" ggH XS'
!   S95_t1(x)%xmin=110.0D0
!   S95_t1(x)%xmax=200.0D0
!   S95_t1(x)%sep=5.0D0 
!   S95_t1(x)%deltax=0.0D0 
!   filename(x)='CDF_H-WW_3.6fb_9022_interpol'

  !NEW! not yet in OB's code
  !x=x+1 
  !S95_t1(x)%id=9023
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 9764,"new" ggH XS'
  !S95_t1(x)%xmin=110.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=5.0D0 
!   S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_H-WW_3.6fb_9023_interpol'

!   x=x+1 
!   S95_t1(x)%id=3493
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt='CDF'
!   S95_t1(x)%label='[hep-ex] arXiv:0803.3493v1 (CDF)'
!   S95_t1(x)%xmin=110.0D0
!   S95_t1(x)%xmax=150.0D0
!   S95_t1(x)%sep=5.0D0 
!   filename(x)='CDF_WH_lnubb_1fb_3493_interpol'

  !x=x+1 
  !S95_t1(x)%id=0710 
  !S95_t1(x)%particle_x=Hneut 
  !S95_t1(x)%expt='CDF' 
  !S95_t1(x)%label='CDF Note XXXX,hwwmenn_090710' 
  !S95_t1(x)%xmin=110.0D0  
  !S95_t1(x)%xmax=200.0D0 
  !S95_t1(x)%sep=5.0D0  
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='CDF_H-WW_4.8fb_0710_interpol' 

  !x=x+1 
  !S95_t1(x)%id=5984
  !S95_t1(x)%particle_x=Hneut 
  !S95_t1(x)%expt=' D0' 
  !S95_t1(x)%label='D0 Note 5984,high mass' 
  !S95_t1(x)%xmin=155.0D0  
  !S95_t1(x)%xmax=200.0D0 
  !S95_t1(x)%sep=5.0D0  
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='D0_SM_combined_5984_highmassonly' 

  !x=x+1 
  !S95_t1(x)%id=3155 
  !S95_t1(x)%particle_x=Hneut 
  !S95_t1(x)%expt='CDF' 
  !S95_t1(x)%label='[hep-ex] arXiv:0905.3155 (CDF)' 
  !S95_t1(x)%xmin=110.0D0  
  !S95_t1(x)%xmax=150.0D0 
  !S95_t1(x)%sep=5.0D0  
  !filename(x)='CDF_WH_lnubb_1.9fb_3155_interpol' 

!   x=x+1 
!   S95_t1(x)%id=9997
!   S95_t1(x)%particle_x=Hneut
!   S95_t1(x)%expt='TCB'
!   S95_t1(x)%label='arXiv:0911.3930 (TEVNPHWG), MH>=160GeV'!CDF Note 9998, D0 Note 5983
!   S95_t1(x)%xmin=160.0D0
!   S95_t1(x)%xmax=200.0D0
!   S95_t1(x)%sep=5.0D0 
!   S95_t1(x)%deltax=0.0D0 
!   filename(x)='CDF_D0_SM_combined_2.1-5.4fb_9998-5983_bayesian_highmassonly'

  !x=x+1 
  !S95_t1(x)%id=6039
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt='TCB'
  !S95_t1(x)%label='CDF Note 10101, D0 Note 6039'
  !S95_t1(x)%xmin=110.0D0
  !S95_t1(x)%xmax=260.0D0
  !S95_t1(x)%sep=5.0D0 
  !filename(x)='CDF_D0_combined_gg-H-WW_4.8-5.4fb_6039_bayesian_interpol'

  !x=x+1 
  !S95_t1(x)%id=6006
  !S95_t1(x)%particle_x=Hneut
  !S95_t1(x)%expt=' D0'
  !S95_t1(x)%label='D0 Note 6006'
  !S95_t1(x)%xmin=115.0D0
  !S95_t1(x)%xmax=200.0D0
  !S95_t1(x)%sep=5.0D0 
  !S95_t1(x)%deltax=0.0D0 
  !filename(x)='D0_H-WW_ll_5.4fb_6006'

  !x=x+1 
  !S95_t1(x)%id=8353
  !S95_t1(x)%particle_x=Hplus
  !S95_t1(x)%expt='CDF'
  !S95_t1(x)%label='CDF Note 8353'
  !S95_t1(x)%xmin=80.0D0
  !S95_t1(x)%xmax=120.0D0
  !S95_t1(x)%sep=10.0D0 
  !filename(x)='CDF_t-Hplusb_8353'

  ! checks we've filled the whole array
  if(x.ne.xend)then
   stop'error in initializetables1 (a)'
  endif 
 
  ! do loop to read in S95 tables 
  col=3
  do x=xbeg,xend
   S95_t1(x)%nx=nint((S95_t1(x)%xmax-S95_t1(x)%xmin)/S95_t1(x)%sep)+1
   allocate(S95_t1(x)%dat(S95_t1(x)%nx,col-1))
  enddo

  open(file_id_common2,file = trim(adjustl(pathname))//'Expt_tables/' // &
      &  'S95_t1.binary',form='unformatted')

  read(file_id_common2,iostat=ios)S95_t1(xbeg)%dat

  if(ios.eq.0)then

    do x=xbeg+1,xend
     read(file_id_common2)S95_t1(x)%dat
    enddo

  else           
    rewind(file_id_common2)
    do x=xbeg,xend
     fullfilename=trim(adjustl(pathname))//'Expt_tables/' &
              &   //trim(adjustl(S95_t1(x)%expt))//'tables/' &
            &   //trim(filename(x))//'.txt'
      

     call read_tabletype1(S95_t1(x),5,col,fullfilename) 
#ifndef WEBVERSION     
     write(file_id_common2)S95_t1(x)%dat
#endif     
    enddo
  endif   
       
  close(file_id_common2)

  deallocate(filename)
             
 end subroutine initializetables1
 
 !************************************************************            
 subroutine read_tabletype1(t1,skip,col,fullfilename)
 !************************************************************       
 !fills t1%dat
  !--------------------------------------input
  type(table1) :: t1  
  integer :: skip,col
  character(LEN=*) :: fullfilename
  !-----------------------------------internal
  integer :: i,n      
  double precision :: xdummy,xdummy_store
  !-------------------------------------------

  t1%dat=0.0D0

  open(file_id_1, file=(trim(fullfilename)))
   
  do i=1,skip
   read(file_id_1,*) !skip lines
  enddo 

  xdummy_store = t1%xmin-t1%sep
  do i=1,t1%nx
   read(file_id_1,*)xdummy,(t1%dat(i,n),n=1,col-1) 

   ! checks that x are evenly spaced as expected
   if((abs(xdummy-xdummy_store-t1%sep).gt.1.0D-7) &
     &  .or.(abs(xdummy-(t1%xmin+dble(i-1)*t1%sep)).gt.1.0D-7))then
    write(*,*)t1%id,xdummy,t1%xmin+dble(i-1)*t1%sep
    stop 'error in read_tabletype1 (a1)'
   endif           

   xdummy_store=xdummy       
       
  enddo  
   
  if(abs(xdummy-t1%xmax).gt.1.0D-7)stop 'error in read_tabletype1 (a2)'

  close(file_id_1) 
  
 end subroutine read_tabletype1
 !************************************************************
end module S95tables_type1
!************************************************************
